/*
 *   @(#) $Id: InetAddressEditor.java 389060 2006-03-27 08:14:32Z trustin $
 *
 *   Copyright 2004 The Apache Software Foundation
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package org.apache.mina.integration.spring;

import java.beans.PropertyEditorSupport;
import java.net.InetAddress;
import java.net.UnknownHostException;

/**
 * Java Bean {@link java.beans.PropertyEditor} which converts Strings into 
 * {@link InetAddress} objects. This may be used together with Spring to be able 
 * to set {@link InetAddress} bean properties, e.g.
 * {@link org.apache.mina.filter.BlacklistFilter#setBlacklist(InetAddress[])}.
 * Simply calls {@link InetAddress#getByName(java.lang.String)} when
 * converting from a String.
 * <p>
 * Use Spring's CustomEditorConfigurer to use this property editor in a Spring
 * configuration file. See chapter 3.14 of the Spring Reference Documentation 
 * for more info.
 * </p>
 * 
 * @author The Apache Directory Project (mina-dev@directory.apache.org)
 * @version $Revision: 389060 $, $Date: 2006-03-27 17:14:32 +0900 (Mon, 27 Mar 2006) $
 * 
 * @see java.net.InetAddress
 */
public class InetAddressEditor extends PropertyEditorSupport
{
    public void setAsText( String text ) throws IllegalArgumentException
    {
        try
        {
            setValue( InetAddress.getByName( text ) );
        }
        catch( UnknownHostException uhe )
        {
            IllegalArgumentException iae = new IllegalArgumentException();
            iae.initCause( uhe );
        }
    }
}
